@@ -68,7 +68,7 @@ class MainWindow(QMainWindow):
 
     def init_ui(self):
         self.setWindowTitle("VenviPy")
-        self.resize(900, 570)
+        self.resize(1100, 690)
         self.center()
         self.setWindowIcon(QIcon(":/img/profile.png"))
 
@@ -125,9 +125,6 @@ class MainWindow(QMainWindow):
         # refresh interpreter table when selecting a custom one in wizard menu
         self.venv_wizard.update_table.connect(self.pop_interpreter_table)
 
-        # populate the combo box in wizard menu
-        self.venv_wizard.basic_settings.pop_combo_box()
-
 
         #]===================================================================[#
         #] ICONS [#==========================================================[#
@@ -263,18 +260,19 @@ class MainWindow(QMainWindow):
         )
 
         # interpreter table
-        interpreter_table = QTableView(
+        self.interpreter_table = QTableView(
             centralwidget,
             selectionBehavior=QAbstractItemView.SelectRows,
             editTriggers=QAbstractItemView.NoEditTriggers,
-            alternatingRowColors=True
+            alternatingRowColors=True,
+            sortingEnabled=True
         )
 
         # hide vertical header
-        interpreter_table.verticalHeader().hide()
+        self.interpreter_table.verticalHeader().hide()
 
         # adjust (horizontal) headers
-        h_header_interpreter_table = interpreter_table.horizontalHeader()
+        h_header_interpreter_table = self.interpreter_table.horizontalHeader()
         h_header_interpreter_table.setDefaultAlignment(Qt.AlignLeft)
         h_header_interpreter_table.setDefaultSectionSize(180)
         h_header_interpreter_table.setStretchLastSection(True)
@@ -284,7 +282,7 @@ class MainWindow(QMainWindow):
         self.model_interpreter_table.setHorizontalHeaderLabels(
             ["Version", "Path"]
         )
-        interpreter_table.setModel(self.model_interpreter_table)
+        self.interpreter_table.setModel(self.model_interpreter_table)
 
         #]===================================================================[#
         # spacer between interpreter table and venv table title
@@ -312,7 +310,6 @@ class MainWindow(QMainWindow):
         # adjust horizontal headers
         h_header_venv_table = self.venv_table.horizontalHeader()
         h_header_venv_table.setDefaultAlignment(Qt.AlignLeft)
-        h_header_venv_table.setDefaultSectionSize(120)
         h_header_venv_table.setStretchLastSection(True)
 
         # set table view model
@@ -322,9 +319,15 @@ class MainWindow(QMainWindow):
         )
         self.venv_table.setModel(self.model_venv_table)
 
+        # adjust column width
+        self.venv_table.setColumnWidth(0, 225)
+        self.venv_table.setColumnWidth(1, 120)
+        self.venv_table.setColumnWidth(2, 100)
+        self.venv_table.setColumnWidth(3, 80)
+
         # add widgets to layout
         v_layout_1.addWidget(interpreter_table_label)
-        v_layout_1.addWidget(interpreter_table)
+        v_layout_1.addWidget(self.interpreter_table)
         v_layout_1.addItem(spacer_item_2)
         v_layout_1.addLayout(h_layout_1)
         h_layout_1.addWidget(self.venv_table_label)
@@ -503,7 +506,7 @@ class MainWindow(QMainWindow):
         self.venv_table.setEnabled(state)
 
 
-    @pyqtSlot(str)
+    @pyqtSlot()
     def pop_interpreter_table(self):
         """
         Populate the interpreter table view.
@@ -523,6 +526,9 @@ class MainWindow(QMainWindow):
                         self.model_interpreter_table.setItem(
                             0, i, QStandardItem(text)
                         )
+                        #if sys.executable in info["PYTHON_PATH"]:
+                            #print(sys.executable)
+
                     print(f"[PYTHON]: {info}")
 
 
@@ -545,15 +551,30 @@ class MainWindow(QMainWindow):
 
 
     def update_label(self):
-        active_dir_str = get_active_dir_str()
-        self.venv_table_label.setText(
-            f'<span style="font-size: 13pt;">\
-                <b>Virtual environments:</b>\
-            </span>\
-            <span style="font-size: 13pt; color: #0059ff;">\
-                {active_dir_str}\
+        """
+        Show the currently selected folder containing
+        virtual environments.
+        """
+        head = (
+            '<span style="font-size: 13pt;">\
+                    <b>Virtual environments:</b>\
+                </span>'
+        )
+        no_folder = (
+            '<span style="font-size: 13pt; color: #ff0000;">\
+                <i> --- please select a folder containing virtual environments</i>\
             </span>'
         )
+        with_folder = (
+            f'<span style="font-size: 13pt; color: #0059ff;">\
+                {get_active_dir_str()}\
+            </span>'
+        )
+
+        if get_active_dir_str() != "":
+            self.venv_table_label.setText(f"{head}{with_folder}")
+        else:
+            self.venv_table_label.setText(f"{head}{no_folder}")
 
 
     def select_active_dir(self):
@@ -596,6 +617,7 @@ def main():
     main_window = MainWindow()
     get_python_installs()
     main_window.pop_interpreter_table()
+    main_window.venv_wizard.basic_settings.pop_combo_box()
     main_window.pop_venv_table()
     main_window.update_label()
     main_window.show()
